@@ -14,13 +14,13 @@ from engine.config import (
 )
 from engine.exceptions import DatamapNotCSVException
 from engine.repository.datamap import InMemorySingleDatamapRepository
-from engine.repository.master import MasterOutputRepository
+from engine.repository.master import MasterOutputRepository, ValidationOnlyRepository
 from engine.repository.templates import (
     InMemoryPopulatedTemplatesRepository,
     MultipleTemplatesWriteRepo,
 )
 from engine.use_cases.output import WriteMasterToTemplates
-from engine.use_cases.parsing import CreateMasterUseCase
+from engine.use_cases.parsing import CreateMasterUseCaseWithValidation, CreateMasterUseCase
 from engine.utils.extraction import data_validation_report, datamap_reader
 from openpyxl import load_workbook
 
@@ -90,7 +90,7 @@ def write_master_to_templates(
     uc.execute()
 
 
-def import_and_create_master(echo_funcs, datamap=None):
+def import_and_create_master(echo_funcs, datamap=None, **kwargs):
     """Import all spreadsheet files from input directory and process with datamap.
 
     echo_func - a function sent from the front-end interface allowing for suitable output (stdout, etc)
@@ -106,27 +106,47 @@ def import_and_create_master(echo_funcs, datamap=None):
     )
     setattr(engine.use_cases.parsing, "ECHO_FUNC_WHITE", echo_funcs["click_echo_white"])
 
-    tmpl_repo = InMemoryPopulatedTemplatesRepository(Config.PLATFORM_DOCS_DIR / "input")
     master_fn = Config.config_parser["DEFAULT"]["master file name"]
+    if kwargs.get("rowlimit"):
+        Config.TEMPLATE_ROW_LIMIT = kwargs.get("rowlimit")
+
+    if kwargs.get("inputdir"):
+        inputdir = kwargs.get("inputdir")
+    else:
+        inputdir = Config.PLATFORM_DOCS_DIR / "input"
+    if kwargs.get("validationonly"):
+        output_repo = ValidationOnlyRepository
+        master_fn = ""
+    else:
+        output_repo = MasterOutputRepository
+
+    if Config.TEMPLATE_ROW_LIMIT < 50:
+        logger.warning(
+            f"Row limit is set to {Config.TEMPLATE_ROW_LIMIT} (default is 500). This may be unintentionally low. Check datamaps import templates --help"
+        )
+    else:
+        logger.info(f"Row limit is set to {Config.TEMPLATE_ROW_LIMIT}.")
+
+    tmpl_repo = InMemoryPopulatedTemplatesRepository(inputdir)
     if datamap:
         dm_fn = datamap
     else:
         dm_fn = Config.config_parser["DEFAULT"]["datamap file name"]
     dm = Path(tmpl_repo.directory_path) / dm_fn
     dm_repo = InMemorySingleDatamapRepository(dm)
-    output_repo = MasterOutputRepository
-    uc = CreateMasterUseCase(dm_repo, tmpl_repo, output_repo)
+    if dm_repo.is_typed:
+        uc = CreateMasterUseCaseWithValidation(dm_repo, tmpl_repo, output_repo)
+    else:
+        if output_repo == ValidationOnlyRepository:
+            logger.critical("Cannot validate data. The datamap needs to have a 'type' column.")
+            sys.exit(1)
+        uc = CreateMasterUseCase(dm_repo, tmpl_repo, output_repo)
     try:
         uc.execute(master_fn)
     except FileNotFoundError as e:
         raise FileNotFoundError(e)
     except DatamapNotCSVException:
         raise
-    logger.info(
-        "{} successfully created in {}\n".format(
-            master_fn, Path(Config.PLATFORM_DOCS_DIR / "output")
-        )
-    )
 
 
 def delete_config(config) -> None:
