@@ -5,7 +5,6 @@ from pathlib import Path
 from typing import Generator, List
 
 import pytest
-
 from engine.config import Config
 from engine.domain.datamap import DatamapLine, DatamapLineValueType
 from engine.domain.template import TemplateCell
@@ -93,6 +92,28 @@ def doc_directory():
     shutil.rmtree(pth)
 
 
+@pytest.fixture
+def template_with_empty_cells_expected_by_datamap():
+    here = os.path.abspath(os.curdir)
+    return Path(
+        os.path.join(
+            here,
+            "tests/resources/test_template_with_empty_cells_expected_by_datamap.xlsm",
+        )
+    )
+
+
+@pytest.fixture
+def datamap_match_test_template_with_missing_val_match_template_equiv():
+    here = os.path.abspath(os.curdir)
+    return Path(
+        os.path.join(
+            here,
+            "tests/resources/datamap_match_test_template_with_missing_val_match_template_equiv.csv",
+        )
+    )
+
+
 @pytest.fixture
 def template_with_introduction_sheet() -> Path:
     here = os.path.abspath(os.curdir)
@@ -107,6 +128,12 @@ def template() -> Path:
     return Path(os.path.join(here, "tests/resources/test_template.xlsx"))
 
 
+@pytest.fixture
+def template_incorrect_type() -> Path:
+    here = os.path.abspath(os.curdir)
+    return Path(os.path.join(here, "tests/resources/test_template_incorrect_type.xlsx"))
+
+
 @pytest.fixture
 def bad_sheet_template() -> Path:
     here = os.path.abspath(os.curdir)
@@ -151,6 +178,33 @@ def datamap() -> Path:
     return Path(os.path.join(here, "tests/resources/datamap.csv"))
 
 
+@pytest.fixture
+def datamap_no_type_col_matches_test_template() -> Path:
+    here = os.path.abspath(os.curdir)
+    return Path(
+        os.path.join(
+            here, "tests/resources/datamap_no_type_col_matches_test_template.csv"
+        )
+    )
+
+
+@pytest.fixture
+def datamap_match_test_template_incorrect_type_descriptor() -> Path:
+    here = os.path.abspath(os.curdir)
+    return Path(
+        os.path.join(
+            here,
+            "tests/resources/datamap_match_test_template_incorrect_type_descriptor.csv",
+        )
+    )
+
+
+@pytest.fixture
+def datamap_missing_one_type() -> Path:
+    here = os.path.abspath(os.curdir)
+    return Path(os.path.join(here, "tests/resources/datamap_missing_one_type.csv"))
+
+
 @pytest.fixture
 def datamap_reduced() -> Path:
     here = os.path.abspath(os.curdir)
@@ -248,6 +302,7 @@ def mock_config(monkeypatch):
         "DATAMAPS_LIBRARY_CONFIG_FILE",
         Path("/tmp/.config/datamaps-data/config.ini"),
     )
+    monkeypatch.setattr(Config, "FULL_PATH_OUTPUT", Config.PLATFORM_DOCS_DIR / "output")
     yield Config
     try:
         shutil.rmtree(Config.DATAMAPS_LIBRARY_DATA_DIR)
