@@ -2,7 +2,7 @@ import hashlib
 
 from engine.use_cases.parsing import extract_from_multiple_xlsx_files
 from engine.utils.extraction import (
-    _get_xlsx_files,
+    get_xlsx_files,
     _hash_single_file,
     _hash_target_files,
 )
@@ -17,7 +17,7 @@ def test_hash_of_single_file(resources):
 
 def test_hash_of_target_files(resources):
     test_file_name = "test_template.xlsx"
-    excel_files = _get_xlsx_files(resources)
+    excel_files = get_xlsx_files(resources)
     test_file = [x for x in excel_files if x.name == test_file_name][0]
     digest_of_test_file = hashlib.md5(open(test_file, "rb").read()).digest().hex()
     get_hashes = _hash_target_files(excel_files)
@@ -27,7 +27,7 @@ def test_hash_of_target_files(resources):
 
 def test_group_data_by_source_file(resources):
     test_file_name = "test_template.xlsx"
-    excel_files = _get_xlsx_files(resources)
+    excel_files = get_xlsx_files(resources)
     test_file = [x for x in excel_files if x.name == test_file_name][0]
     digest_of_test_file = hashlib.md5(open(test_file, "rb").read()).digest().hex()
     dataset = extract_from_multiple_xlsx_files(excel_files)
